@@ -37,8 +37,7 @@ impl Font {
             TextureDimension::D2,
             alpha
                 .iter()
-                .map(|a| vec![255, 255, 255, (*a * 255.0) as u8])
-                .flatten()
+                .flat_map(|a| vec![255, 255, 255, (*a * 255.0) as u8])
                 .collect::<Vec<u8>>(),
             TextureFormat::Rgba8UnormSrgb,
         )
